Comment

Struct Comment 

pub struct Comment { /* private fields */ }
A comment rule.

Comments do not generate tokens, unlike most rules. Instead, they are attached to the span of a token, and can be inspected through Span::comments().

Implementations

Source

impl Comment

pub fn line(delim: impl Into<Yarn>) -> Self

Creates a new line comment. Line comments cannot nest, and run from starting delimiter (which is something like // or #) to the next '\n' character (not including it).

pub fn block(open: impl Into<Yarn>, close: impl Into<Yarn>) -> Self

Creates a new nestable block comment with paired delimiters.

pub fn nesting(bracket: Bracket) -> Self

Creates a new comment that can nest. For example, Rust block comments can nest: /* /* */ */

pub fn non_nesting(bracket: Bracket) -> Self

Creates a new comment that can’t nest. For example, a line comment is a non-nesting comment where a newline ‘\n’ is the closing delimiter.