pub struct SpanId(/* private fields */);Expand description
An interned Span.
Most tokens’ spans will never be inspected after lexing, so it’s better to make them small for memory saving reasons. This abstraction allows the library to optimize internal handling of spans over time.
This type is just a numeric ID; in order to do anything with it, you’ll
need to call one of the functions in Spanned.