pub struct Eof<'lex> { /* private fields */ }Expand description
A special token for the end of a file.
The main purpose of this token is to hold any comment spans that are after
all the “real” tokens. For example, a file consisting of only comments will
have a single Eof token after lexing, and will include all of those
comments within.